# nomiden

## What is it?

**nomiden** is a Python package that provides information extraction from Indonesian ID Numbers, i.e. NIK (Nomor Induk Kependudukan) and KK (Kartu Keluarga).

## Main Features
Here are the things that **nomiden** can do for you:

  - Retreive regional information 
    - Province
    - City
    - District
  - Retreive gender information (NIK only)
  - Retreive birth information (NIK only)
    - Age
    - Birthday (e.g. 15 June 2000)
    - Birth date
    - Birth month
    - Birth year
    - Birth in datetime
  - Retreive registration information (KK only)
    - Registration day (e.g. 15 June 2000)
    - Registration date
    - Registration month
    - Registration year
    - Registration in datetime
  - Registration order
  - Complete information in a dictionary

## Where to get it
The source code is currently hosted on GitHub at: https://github.com/divakartika/nomiden

**nomiden** is available at the [Python Package Index (PyPI)](https://pypi.org/project/nomiden/).

## Dependencies
- [Pandas - Supports data-related operations](https://pandas.pydata.org)

## License
[MIT](LICENSE)

## Documentation
[nomiden Documentation](https://divakartika.notion.site/nomiden-Documentation-50ed0573bd7c44bc8337472cfbdb24d3) 

## Getting Help & Discussion

For usage questions and development discussions, feel free to contact diva@algorit.ma.